package cn.com.qmth.stmms.admin.report;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;

import cn.com.qmth.stmms.biz.report.utils.ReportSubjectTeacherDTO;
import cn.com.qmth.stmms.admin.exam.BaseExamController;
import cn.com.qmth.stmms.biz.report.model.ReportSubjectTeacher;
import cn.com.qmth.stmms.biz.report.query.ReportSubjectQuery;
import cn.com.qmth.stmms.biz.report.service.ReportSubjectTeacherService;
import cn.com.qmth.stmms.common.annotation.Logging;
import cn.com.qmth.stmms.common.domain.WebUser;
import cn.com.qmth.stmms.common.enums.LogType;
import cn.com.qmth.stmms.common.utils.ExportExcel;
import cn.com.qmth.stmms.common.utils.RequestUtils;

/**
 * 课程总评成绩分析
 *
 * @author xuwenjin
 * @date 2019-04-16 17:26
 */
@Controller
@RequestMapping("/admin/exam/reportSubjectTeacher")
public class ReportSubjectTeacherController extends BaseExamController {

    protected static Logger log = LoggerFactory.getLogger(ReportSubjectTeacherController.class);

    @Autowired
    private ReportSubjectTeacherService reportSubjectTeacherService;

    @Logging(menu = "课程总评分析", type = LogType.QUERY)
    @RequestMapping
    public String list(Model model, HttpServletRequest request, ReportSubjectQuery query) {
        WebUser webuser = RequestUtils.getWebUser(request);
        int examId = getSessionExamId(request);
        query.setExamId(examId);
        query.setPageNumber(1);
        query.setPageSize(Integer.MAX_VALUE);
        if (StringUtils.isNotBlank(query.getSubjectCode())) {
            List<ReportSubjectTeacher> reportSubjectTeacherList = reportSubjectTeacherService.findByQuery(query);
            model.addAttribute("list", reportSubjectTeacherList);
        }
        model.addAttribute("subjectList", getExamSubject(examId, webuser));
        model.addAttribute("query", query);
        return "modules/report/reportSubjectTeacher";
    }

    @Logging(menu = "课程总评分析导出", type = LogType.EXPORT)
    @RequestMapping("/export")
    public String export(ReportSubjectQuery query, HttpServletRequest request, HttpServletResponse response,
            RedirectAttributes redirectAttributes) {
        int examId = getSessionExamId(request);
        query.setExamId(examId);
        query.setPageNumber(1);
        query.setPageSize(Integer.MAX_VALUE);
        List<ReportSubjectTeacher> result = reportSubjectTeacherService.findByQuery(query);
        List<ReportSubjectTeacherDTO> list = new ArrayList<>();
        for (ReportSubjectTeacher r : result) {
            list.add(new ReportSubjectTeacherDTO(r));
        }
        String fileName = "课程总评成绩分析.xlsx";
        try {
            new ExportExcel("课程总评成绩分析", ReportSubjectTeacherDTO.class).setDataList(list).write(response, fileName)
                    .dispose();
            return null;
        } catch (Exception e) {
            addMessage(redirectAttributes, "导出成绩失败！" + e.getMessage());
            return "redirect:/admin/exam/reportSubjectTeacherClass";
        }
    }
}
